<?php
/**
 * ץꥱ̥󥯥饹
 *
 * @access    public
 * @package   {APP_NAME}
 * @author    {author}
 * @copyright {copyright}
 * @version   $Id: AppAction.php,v 1.4 2008/06/20 17:41:54 seasonstream Exp $
 */
class AppAction extends SyL_Action
{
    /**
     * ᥽åɼ¹˼¹Ԥ᥽å
     *
     * @access public
     * @param object ǡ֥
     * @param object ƥȥ֥
     */
    function preExecute(&$data, &$context)
    {
        parent::preExecute($data, $context);
    }

    /**
     * ᥽åɼ¹˼¹Ԥ븡ڥ᥽å
     * 
     * @access public
     * @param object ǡ֥
     * @param object ƥȥ֥
     */
    function validate(&$data, &$context)
    {
        parent::validate($data, $context);
    }

    /**
     * ᥽åɼ¹Ը˼¹Ԥ᥽å
     * 
     * @access public
     * @param object ǡ֥
     * @param object ƥȥ֥
     */
    function postExecute(&$data, &$context)
    {
        parent::postExecute($data, $context);
    }
}

?>
